#ifndef NT2_INCLUDE_FUNCTIONS_BITINTEGER_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_BITINTEGER_HPP_INCLUDED

#include <nt2/ieee/include/functions/bitinteger.hpp>

#endif
